==> vertx-rx-java3-4.4.8-sources.jar: io/vertx/rxjava3/grpc/common/GrpcMessageDecoder.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.rxjava3.grpc.common;

import io.vertx.rxjava3.RxHelper;
import io.vertx.rxjava3.ObservableHelper;
import io.vertx.rxjava3.FlowableHelper;
import io.vertx.rxjava3.impl.AsyncResultMaybe;
import io.vertx.rxjava3.impl.AsyncResultSingle;
import io.vertx.rxjava3.impl.AsyncResultCompletable;
import io.vertx.rxjava3.WriteStreamObserver;
import io.vertx.rxjava3.WriteStreamSubscriber;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.grpc.common.GrpcMessageDecoder.class)
public class GrpcMessageDecoder<T> {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GrpcMessageDecoder that = (GrpcMessageDecoder) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<GrpcMessageDecoder> __TYPE_ARG = new TypeArg<>(    obj -> new GrpcMessageDecoder((io.vertx.grpc.common.GrpcMessageDecoder) obj),
    GrpcMessageDecoder::getDelegate
  );

  private final io.vertx.grpc.common.GrpcMessageDecoder<T> delegate;
  public final TypeArg<T> __typeArg_0;
  
  public GrpcMessageDecoder(io.vertx.grpc.common.GrpcMessageDecoder delegate) {
    this.delegate = delegate;
    this.__typeArg_0 = TypeArg.unknown();  }

  public GrpcMessageDecoder(Object delegate, TypeArg<T> typeArg_0) {
    this.delegate = (io.vertx.grpc.common.GrpcMessageDecoder)delegate;
    this.__typeArg_0 = typeArg_0;
  }

  public io.vertx.grpc.common.GrpcMessageDecoder getDelegate() {
    return delegate;
  }


  public T decode(io.vertx.rxjava3.grpc.common.GrpcMessage msg) { 
    T ret = (T)__typeArg_0.wrap(delegate.decode(msg.getDelegate()));
    return ret;
  }

  public static <T> io.vertx.rxjava3.grpc.common.GrpcMessageDecoder<T> unmarshaller(io.grpc.MethodDescriptor.Marshaller<T> desc) { 
    io.vertx.rxjava3.grpc.common.GrpcMessageDecoder<T> ret = io.vertx.rxjava3.grpc.common.GrpcMessageDecoder.newInstance((io.vertx.grpc.common.GrpcMessageDecoder)io.vertx.grpc.common.GrpcMessageDecoder.unmarshaller(desc), TypeArg.unknown());
    return ret;
  }

  public static final io.vertx.rxjava3.grpc.common.GrpcMessageDecoder<io.vertx.rxjava3.core.buffer.Buffer> IDENTITY = io.vertx.rxjava3.grpc.common.GrpcMessageDecoder.newInstance((io.vertx.grpc.common.GrpcMessageDecoder)io.vertx.grpc.common.GrpcMessageDecoder.IDENTITY, new TypeArg<io.vertx.rxjava3.core.buffer.Buffer>(o0 -> io.vertx.rxjava3.core.buffer.Buffer.newInstance((io.vertx.core.buffer.Buffer)o0), o0 -> o0.getDelegate()));
  public static final io.vertx.rxjava3.grpc.common.GrpcMessageDecoder<io.vertx.rxjava3.core.buffer.Buffer> GZIP = io.vertx.rxjava3.grpc.common.GrpcMessageDecoder.newInstance((io.vertx.grpc.common.GrpcMessageDecoder)io.vertx.grpc.common.GrpcMessageDecoder.GZIP, new TypeArg<io.vertx.rxjava3.core.buffer.Buffer>(o0 -> io.vertx.rxjava3.core.buffer.Buffer.newInstance((io.vertx.core.buffer.Buffer)o0), o0 -> o0.getDelegate()));
  public static <T> GrpcMessageDecoder<T> newInstance(io.vertx.grpc.common.GrpcMessageDecoder arg) {
    return arg != null ? new GrpcMessageDecoder<T>(arg) : null;
  }

  public static <T> GrpcMessageDecoder<T> newInstance(io.vertx.grpc.common.GrpcMessageDecoder arg, TypeArg<T> __typeArg_T) {
    return arg != null ? new GrpcMessageDecoder<T>(arg, __typeArg_T) : null;
  }

}

==> vertx-rx-java3-4.5.20-sources.jar: io/vertx/rxjava3/grpc/common/GrpcMessageDecoder.java <==
/*
 * Copyright 2014 Red Hat, Inc.
 *
 * Red Hat licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package io.vertx.rxjava3.grpc.common;

import io.vertx.rxjava3.RxHelper;
import io.vertx.rxjava3.ObservableHelper;
import io.vertx.rxjava3.FlowableHelper;
import io.vertx.rxjava3.impl.AsyncResultMaybe;
import io.vertx.rxjava3.impl.AsyncResultSingle;
import io.vertx.rxjava3.impl.AsyncResultCompletable;
import io.vertx.rxjava3.WriteStreamObserver;
import io.vertx.rxjava3.WriteStreamSubscriber;
import java.util.Map;
import java.util.Set;
import java.util.List;
import java.util.Iterator;
import java.util.function.Function;
import java.util.stream.Collectors;
import io.vertx.core.Handler;
import io.vertx.core.AsyncResult;
import io.vertx.core.json.JsonObject;
import io.vertx.core.json.JsonArray;
import io.vertx.lang.rx.RxDelegate;
import io.vertx.lang.rx.RxGen;
import io.vertx.lang.rx.TypeArg;
import io.vertx.lang.rx.MappingIterator;


@RxGen(io.vertx.grpc.common.GrpcMessageDecoder.class)
public class GrpcMessageDecoder<T> implements RxDelegate {

  @Override
  public String toString() {
    return delegate.toString();
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GrpcMessageDecoder that = (GrpcMessageDecoder) o;
    return delegate.equals(that.delegate);
  }
  
  @Override
  public int hashCode() {
    return delegate.hashCode();
  }

  public static final TypeArg<GrpcMessageDecoder> __TYPE_ARG = new TypeArg<>(    obj -> new GrpcMessageDecoder((io.vertx.grpc.common.GrpcMessageDecoder) obj),
    GrpcMessageDecoder::getDelegate
  );

  private final io.vertx.grpc.common.GrpcMessageDecoder<T> delegate;
  public final TypeArg<T> __typeArg_0;
  
  public GrpcMessageDecoder(io.vertx.grpc.common.GrpcMessageDecoder delegate) {
    this.delegate = delegate;
    this.__typeArg_0 = TypeArg.unknown();  }

  public GrpcMessageDecoder(Object delegate, TypeArg<T> typeArg_0) {
    this.delegate = (io.vertx.grpc.common.GrpcMessageDecoder)delegate;
    this.__typeArg_0 = typeArg_0;
  }

  @Override 
  public io.vertx.grpc.common.GrpcMessageDecoder getDelegate() {
    return delegate;
  }


  public T decode(io.vertx.rxjava3.grpc.common.GrpcMessage msg) { 
    T ret = (T)__typeArg_0.wrap(delegate.decode(msg.getDelegate()));
    return ret;
  }

  public static <T> io.vertx.rxjava3.grpc.common.GrpcMessageDecoder<T> unmarshaller(io.grpc.MethodDescriptor.Marshaller<T> desc) { 
    io.vertx.rxjava3.grpc.common.GrpcMessageDecoder<T> ret = io.vertx.rxjava3.grpc.common.GrpcMessageDecoder.newInstance((io.vertx.grpc.common.GrpcMessageDecoder)io.vertx.grpc.common.GrpcMessageDecoder.unmarshaller(desc), TypeArg.unknown());
    return ret;
  }

  public static final io.vertx.rxjava3.grpc.common.GrpcMessageDecoder<io.vertx.rxjava3.core.buffer.Buffer> IDENTITY = io.vertx.rxjava3.grpc.common.GrpcMessageDecoder.newInstance((io.vertx.grpc.common.GrpcMessageDecoder)io.vertx.grpc.common.GrpcMessageDecoder.IDENTITY, new TypeArg<io.vertx.rxjava3.core.buffer.Buffer>(o0 -> io.vertx.rxjava3.core.buffer.Buffer.newInstance((io.vertx.core.buffer.Buffer)o0), o0 -> o0.getDelegate()));
  public static final io.vertx.rxjava3.grpc.common.GrpcMessageDecoder<io.vertx.rxjava3.core.buffer.Buffer> GZIP = io.vertx.rxjava3.grpc.common.GrpcMessageDecoder.newInstance((io.vertx.grpc.common.GrpcMessageDecoder)io.vertx.grpc.common.GrpcMessageDecoder.GZIP, new TypeArg<io.vertx.rxjava3.core.buffer.Buffer>(o0 -> io.vertx.rxjava3.core.buffer.Buffer.newInstance((io.vertx.core.buffer.Buffer)o0), o0 -> o0.getDelegate()));
  public static <T> GrpcMessageDecoder<T> newInstance(io.vertx.grpc.common.GrpcMessageDecoder arg) {
    return arg != null ? new GrpcMessageDecoder<T>(arg) : null;
  }

  public static <T> GrpcMessageDecoder<T> newInstance(io.vertx.grpc.common.GrpcMessageDecoder arg, TypeArg<T> __typeArg_T) {
    return arg != null ? new GrpcMessageDecoder<T>(arg, __typeArg_T) : null;
  }

}
